@@ -328,19 +328,8 @@ newMultispeciesParams <- function(
 # The reason we list `interaction` explicitly rather than including it in
 # the `...` is for backwards compatibility. It used to be the second argument.
 setParams <- function(params, interaction = NULL, ...) {
-    # Check w_max
-    # This wasn't checked by `validSpeciesParams()` because that function does
-    # not have access to the full weight grid.
-    w_max <- max(params@w) + 1e-6 # The 1e-6 is to avoid rounding errors
-    if (any(params@species_params$w_max > w_max)) {
-        stop("The maximum weight of a species is larger than the maximum ",
-             "weight of the model. ")
-    }
-    # Recalculate ft_mask in case w_max has changed
-    params@ft_mask <- t(sapply(params@species_params$w_max, 
-                               function(x) params@w_full < x))
+    params <- validParams(params)
     
-    params <- suppressWarnings(validParams(params))
     params <- setInteraction(params, interaction)
     params <- setPredKernel(params, ...)
     params <- setMaxIntakeRate(params, ...)
