@@ -1,6 +1,6 @@
 # get_initial_n ----
 test_that("get_initial_n is working properly", {
-    params <- newMultispeciesParams(NS_species_params_gears, inter)
+    params <- newMultispeciesParams(NS_species_params_gears, inter, info_level = 0)
     n <- get_initial_n(params)
     no_sp <- nrow(params@species_params)
     for (i in 1:no_sp) {
@@ -14,6 +14,6 @@ test_that("get_initial_n is working properly", {
         slopes[i] <- (log(n[i, min(n_idx)]) - log(n[i, max(n_idx)])) / 
             (log(params@w[min(n_idx)]) - log(params@w[max(n_idx)]))
     }
-    expect_that(slopes, equals(rep(slopes[1], no_sp)))
+    expect_equal(slopes, rep(slopes[1], no_sp))
     # Check that slopes = slope0
 })
