@@ -36,23 +36,29 @@ test_that("addSpecies handles gear params correctly", {
     # If no initial_effort for new gear is provided, it is 0
     # Wrapping in `expect_warning()` to ignore warnings about unrealistic
     # reproductive efficiency
-    expect_warning(pa <- addSpecies(p, sp, gp))
+    (pa <- addSpecies(p, sp, gp)) |>
+        expect_message() |>
+        expect_warning()
     expect_identical(pa@initial_effort,
                      c(knife_edge_gear = 0, gear1 = 0, gear2 = 0))
     expect_identical(nrow(pa@gear_params), 5L)
     
     # effort for existing gear is not changed
     extra_effort <- c(gear1 = 2, gear2 = 3)
-    expect_warning(pa <- addSpecies(p, sp, gp, initial_effort = extra_effort))
+    (pa <- addSpecies(p, sp, gp, initial_effort = extra_effort)) |>
+        expect_message() |>
+        expect_warning()
     expect_identical(pa@initial_effort, c(knife_edge_gear = 0, extra_effort))
     
     effort <- 2
-    expect_error(addSpecies(p, sp, gp, initial_effort = effort),
-                 "The `initial_effort` must be a named list or vector")
+    addSpecies(p, sp, gp, initial_effort = effort) |>
+        expect_message() |>
+        expect_error("The `initial_effort` must be a named list or vector")
     
     effort <- c(knife_edge_gear = 1)
-    expect_error(addSpecies(p, sp, gp, initial_effort = effort),
-                 "The names of the `initial_effort` do not match the names of the new gears.")
+    addSpecies(p, sp, gp, initial_effort = effort) |>
+        expect_message() |>
+        expect_error("The names of the `initial_effort` do not match the names of the new gears.")
 })
 
 test_that("addSpecies handles interaction matrix correctly", {
@@ -66,19 +72,23 @@ test_that("addSpecies handles interaction matrix correctly", {
     
     interaction <- matrix(1:4/4, ncol = 2)
     ones <- matrix(rep(1, 4), ncol = 2)
-    expect_warning(pa <- addSpecies(p, sp, interaction = interaction))
-    expect_equivalent(pa@interaction[3:4, 3:4], interaction)
-    expect_equivalent(pa@interaction[1:2, 3:4], ones)
-    expect_equivalent(pa@interaction[3:4, 1:2], ones)
-    expect_equivalent(pa@interaction[1:2, 1:2], p@interaction)
+    (pa <- addSpecies(p, sp, interaction = interaction)) |>
+        expect_message() |>
+        expect_warning()
+    expect_equal(pa@interaction[3:4, 3:4], interaction, ignore_attr = TRUE)
+    expect_equal(pa@interaction[1:2, 3:4], ones, ignore_attr = TRUE)
+    expect_equal(pa@interaction[3:4, 1:2], ones, ignore_attr = TRUE)
+    expect_equal(pa@interaction[1:2, 1:2], p@interaction, ignore_attr = TRUE)
     
     interaction <- matrix(1:16/16, ncol = 4)
-    expect_warning(pa <- addSpecies(p, sp, interaction = interaction))
-    expect_equivalent(pa@interaction, interaction)
+    (pa <- addSpecies(p, sp, interaction = interaction)) |>
+        expect_message() |>
+        expect_warning("The following species require an unrealistic value greater than 1 for `erepro`: new2")
+    expect_equal(pa@interaction, interaction, ignore_attr = TRUE)
     
-    expect_error(addSpecies(p, sp,
-                            interaction = matrix(1:9, ncol = 3)),
-                 "Interaction matrix has invalid dimensions.")
+    addSpecies(p, sp, interaction = matrix(1:9, ncol = 3)) |>
+        expect_warning() |>
+        expect_error("Interaction matrix has invalid dimensions.")
 })
 test_that("addSpecies works when adding a species with a larger w_max", {
     sp <- data.frame(species = "Blue whale", w_max = 5e4,
@@ -88,14 +98,14 @@ test_that("addSpecies works when adding a species with a larger w_max", {
     # change a slot to test that such changes will be preserved
     params <- setMaxIntakeRate(params, 2 * getMaxIntakeRate(params))
     
-    p <- addSpecies(params, sp)
+    (p <- addSpecies(params, sp)) |>
+        expect_message()
     expect_identical(p@w[1:100], params@w)
     expect_identical(p@w_full[seq_along(params@w_full)], params@w_full)
     expect_lte(5e4, max(p@w))
     # changed rates are preserved
     expect_equal(getMaxIntakeRate(p)[1:12, 1:100],
-                 getMaxIntakeRate(params),
-                 check.attributes = FALSE)
+                 getMaxIntakeRate(params), ignore_attr = TRUE)
 })
 test_that("addSpecies works when adding a species with a smaller w_min", {
     sp <- data.frame(species = "Blue whale", w_max = 5e4, w_min = 1e-5,
@@ -105,14 +115,14 @@ test_that("addSpecies works when adding a species with a smaller w_min", {
     # change a slot to test that such changes will be preserved
     params <- setMaxIntakeRate(params, 2 * getMaxIntakeRate(params))
     
-    p <- addSpecies(params, sp)
+    (p <- addSpecies(params, sp)) |>
+        expect_message()
     expect_equal(p@w[28:127], params@w)
     expect_equal(p@w_full[seq_along(params@w_full)], params@w_full)
     expect_gte(1e-5, min(p@w))
     # changed rates are preserved
     expect_equal(getMaxIntakeRate(p)[1:12, 28:127],
-                 getMaxIntakeRate(params),
-                 check.attributes = FALSE)
+                 getMaxIntakeRate(params), ignore_attr = TRUE)
 })
 
 test_that("addSpecies has other documented properties", {
@@ -121,7 +131,8 @@ test_that("addSpecies has other documented properties", {
                      k_vb = c(4, 1),
                      n = 2 / 3,
                      p = 2 / 3)
-    p <- addSpecies(NS_params, sp)
+    (p <- addSpecies(NS_params, sp)) |>
+        expect_message()
     
     # New species have 0 reproduction level
     expect_equal(getReproductionLevel(p)[13:14],
@@ -146,24 +157,42 @@ test_that("Added species stay at low abundance", {
         a = 0.0085,
         b = 3.11
     )
-    params <- addSpecies(params, species_params)
+    expect_message(params <- addSpecies(params, species_params))
     no_sp <- nrow(params@species_params)
     sim <- project(params, t_max = 1, progress_bar = FALSE)
-    expect_lt(finalN(sim)[no_sp, 1] / initialN(sim)[no_sp, 1], 1.04)
+    expect_lt(finalN(sim)[no_sp, 1] / initialN(sim)[no_sp, 1], 1.05)
 })
 
+test_that("addSpecies preserves both given and other species params", {
+    
+    params <- newTraitParams()
+    params@given_species_params$b <- 3
+    params@species_params$w_mat25 <- params@species_params$w_mat25 * 1.01
+    sp <- data.frame(species = "new",
+                     w_max = 10, test = "test")
+    expect_message(p <- addSpecies(params, sp))
+    no_sp <- nrow(params@species_params)
+    expect_identical(p@species_params$w_mat25[1:no_sp],
+                     params@species_params$w_mat25[1:no_sp])
+    expect_identical(p@given_species_params$b[1:no_sp],
+                     params@given_species_params$b[1:no_sp])
+    expect_in("test", names(p@species_params))
+    expect_in("test", names(p@given_species_params))
+})
 
 # removeSpecies ----
 test_that("removeSpecies works", {
     remove <- NS_species_params$species[2:11]
     reduced <- NS_species_params[!(NS_species_params$species %in% remove), ]
     params <- newMultispeciesParams(NS_species_params, no_w = 20,
-                                    max_w = 39900, min_w_pp = 9e-14)
+                                    max_w = 39900, min_w_pp = 9e-14, 
+                                    info_level = 0)
     p1 <- removeSpecies(params, species = remove)
     expect_equal(nrow(p1@species_params), nrow(params@species_params) - 10)
     p2 <- newMultispeciesParams(reduced, no_w = 20,
-                                max_w = 39900, min_w_pp = 9e-14)
-    expect_equivalent(p1, p2)
+                                max_w = 39900, min_w_pp = 9e-14, info_level = 0)
+    p2@linecolour[2] = "#a08dfb" # update line colour
+    expect_equal(p1, p2, ignore_attr = TRUE)
     sim1 <- project(p1, t_max = 0.4, t_save = 0.4)
     sim2 <- project(p2, t_max = 0.4, t_save = 0.4)
     expect_identical(sim1@n[2, 2, ], sim2@n[2, 2, ])
@@ -189,14 +218,12 @@ test_that("removeSpecies works correctly on gear_params", {
 })
 
 test_that("adding and then removing species leaves params unaltered", {
-    params <- NS_params
-    # TODO: currently NS_params still has factors in gear_params
-    params@gear_params$species <- as.character(params@gear_params$species)
-    params@gear_params$gear <- as.character(params@gear_params$gear)
+    params <- newMultispeciesParams(NS_species_params, info_level = 0)
     # two arbitrary species
     sp <- data.frame(species = c("new1", "new2"),
                      w_max = c(10, 100),
-                     k_vb = c(4, 1),
+                     k_vb = c(4, 2),
+                     test = "test",
                      stringsAsFactors = FALSE)
     # add comments to test that they will be preserved as well
     comment(params) <- "test"
@@ -207,8 +234,9 @@ test_that("adding and then removing species leaves params unaltered", {
     comment(params@pred_kernel) <- NULL
     comment(params@catchability) <- NULL
     comment(params@selectivity) <- NULL
-    params2 <- addSpecies(params, sp) %>%
-        removeSpecies(c("new1", "new2"))
+    (params2 <- addSpecies(params, sp) |>
+        removeSpecies(c("new1", "new2"))) |>
+        expect_message()
     
     # For now the linecolour and linetype are not preserved
     # TODO: fix this in the next overhaul of linecolour and linetype code
@@ -226,11 +254,11 @@ test_that("adding and then removing species leaves params unaltered", {
 # renameSpecies ----
 test_that("renameSpecies works", {
     sp <- NS_species_params
-    p <- newMultispeciesParams(sp)
+    p <- newMultispeciesParams(sp, info_level = 0)
     sp$species <- tolower(sp$species)
     replace <- NS_species_params$species
     names(replace) <- sp$species
-    p2 <- newMultispeciesParams(sp)
+    p2 <- newMultispeciesParams(sp, info_level = 0)
     p2 <- renameSpecies(p2, replace)
     p2@time_modified <- p@time_modified
     p2@time_created <- p@time_created
